@@ -1,7 +1,12 @@
 import sys
 
+from dotenv import load_dotenv
+
 from .cli import app
 
+# Load environment variables from .env file
+load_dotenv()
+
 
 def main():
     try:
