@@ -129,18 +129,24 @@ async def article_searcher(
 async def article_getter(
     pmid: Annotated[
         str,
-        Field(description="PubMed ID (e.g., '38768446' or 'PMC11193658')"),
+        Field(
+            description="Article identifier - either a PubMed ID (e.g., '38768446' or 'PMC11193658') or DOI (e.g., '10.1101/2024.01.20.23288905')"
+        ),
     ],
 ) -> str:
-    """Fetch detailed information for a specific PubMed article.
+    """Fetch detailed information for a specific article.
 
-    Retrieves the full abstract and available text for a PubMed article by its ID.
-    Supports both PMID and PMC IDs.
+    Retrieves the full abstract and available text for an article by its identifier.
+    Supports:
+    - PubMed IDs (PMID) for published articles
+    - PMC IDs for articles in PubMed Central
+    - DOIs for preprints from Europe PMC
 
     Returns formatted text including:
     - Title
     - Abstract
-    - Full text (when available from PMC)
+    - Full text (when available from PMC for published articles)
+    - Source information (PubMed or Europe PMC)
     """
     return await _article_details(
         call_benefit="Fetch detailed article information for analysis",
@@ -596,3 +602,96 @@ async def variant_getter(
         variant_id=variant_id,
         include_external=include_external,
     )
+
+
+@mcp_app.tool()
+@track_performance("biomcp.alphagenome_predictor")
+async def alphagenome_predictor(
+    chromosome: Annotated[
+        str,
+        Field(description="Chromosome (e.g., 'chr7', 'chrX')"),
+    ],
+    position: Annotated[
+        int,
+        Field(description="1-based genomic position of the variant"),
+    ],
+    reference: Annotated[
+        str,
+        Field(description="Reference allele(s) (e.g., 'A', 'ATG')"),
+    ],
+    alternate: Annotated[
+        str,
+        Field(description="Alternate allele(s) (e.g., 'T', 'A')"),
+    ],
+    interval_size: Annotated[
+        int,
+        Field(
+            description="Size of genomic interval to analyze in bp (max 1,000,000)",
+            ge=2000,
+            le=1000000,
+        ),
+    ] = 131072,
+    tissue_types: Annotated[
+        list[str] | str | None,
+        Field(
+            description="UBERON ontology terms for tissue-specific predictions (e.g., 'UBERON:0002367' for external ear)"
+        ),
+    ] = None,
+    significance_threshold: Annotated[
+        float,
+        Field(
+            description="Threshold for significant log2 fold changes (default: 0.5)",
+            ge=0.0,
+            le=5.0,
+        ),
+    ] = 0.5,
+    api_key: Annotated[
+        str | None,
+        Field(
+            description="AlphaGenome API key. Check if user mentioned 'my AlphaGenome API key is...' in their message. If not provided here and no env var is set, user will be prompted to provide one."
+        ),
+    ] = None,
+) -> str:
+    """Predict variant effects on gene regulation using Google DeepMind's AlphaGenome.
+
+    ⚠️ PREREQUISITE: Use the 'think' tool FIRST to plan your analysis strategy!
+
+    AlphaGenome provides state-of-the-art predictions for how genetic variants
+    affect gene regulation, including:
+    - Gene expression changes (RNA-seq)
+    - Chromatin accessibility impacts (ATAC-seq, DNase-seq)
+    - Splicing alterations
+    - Promoter activity changes (CAGE)
+
+    This tool requires:
+    1. AlphaGenome to be installed (see error message for instructions)
+    2. An API key from https://deepmind.google.com/science/alphagenome
+
+    API Key Options:
+    - Provide directly via the api_key parameter
+    - Or set ALPHAGENOME_API_KEY environment variable
+
+    Example usage:
+    - Predict regulatory effects of BRAF V600E mutation: chr7:140753336 A>T
+    - Assess non-coding variant impact on gene expression
+    - Evaluate promoter variants in specific tissues
+
+    Note: This is an optional tool that enhances variant interpretation
+    with AI predictions. Standard annotations remain available via variant_getter.
+    """
+    from biomcp.variants.alphagenome import predict_variant_effects
+
+    # Convert tissue_types to list if needed
+    tissue_types_list = ensure_list(tissue_types) if tissue_types else None
+
+    # Call the prediction function
+    return await predict_variant_effects(
+        chromosome=chromosome,
+        position=position,
+        reference=reference,
+        alternate=alternate,
+        interval_size=interval_size,
+        tissue_types=tissue_types_list,
+        significance_threshold=significance_threshold,
+        api_key=api_key,
+    )
